pub struct Spu { /* private fields */ }Expand description
System protection unit.
Implementations
Sourceimpl Spu
impl Spu
pub const unsafe fn from_ptr(ptr: *mut ()) -> Spu
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn events_ramaccerr(self) -> Reg<u32, RW>
pub const fn events_ramaccerr(self) -> Reg<u32, RW>
A security violation has been detected for the RAM memory space.
Sourcepub const fn events_flashaccerr(self) -> Reg<u32, RW>
pub const fn events_flashaccerr(self) -> Reg<u32, RW>
A security violation has been detected for the flash memory space.
Sourcepub const fn events_periphaccerr(self) -> Reg<u32, RW>
pub const fn events_periphaccerr(self) -> Reg<u32, RW>
A security violation has been detected on one or several peripherals.
Sourcepub const fn publish_ramaccerr(self) -> Reg<Publish, RW>
pub const fn publish_ramaccerr(self) -> Reg<Publish, RW>
Publish configuration for event RAMACCERR.
Sourcepub const fn publish_flashaccerr(self) -> Reg<Publish, RW>
pub const fn publish_flashaccerr(self) -> Reg<Publish, RW>
Publish configuration for event FLASHACCERR.
Sourcepub const fn publish_periphaccerr(self) -> Reg<Publish, RW>
pub const fn publish_periphaccerr(self) -> Reg<Publish, RW>
Publish configuration for event PERIPHACCERR.
Sourcepub const fn flashregion(self, n: usize) -> Flashregion
pub const fn flashregion(self, n: usize) -> Flashregion
Unspecified.